@@ -38,6 +38,7 @@
 #include <QFile>
 #include <QFileInfo>
 #include <QMimeDatabase>
+#include <QRegularExpression>
 
 #include <KPluginFactory>
 #include <KPluginLoader>
@@ -71,7 +72,7 @@ Archive *Archive::create(const QString &fileName, const QString &fixedMimeType,
         return new Archive(NoPlugin, parent);
     }
 
-    Archive *archive;
+    Archive *archive = Q_NULLPTR;
     foreach (Plugin *plugin, offers) {
         archive = create(fileName, plugin, parent);
         // Use the first valid plugin, according to the priority sorting.
@@ -151,11 +152,24 @@ Archive::~Archive()
 
 QString Archive::completeBaseName() const
 {
+    const QString suffix = QFileInfo(fileName()).suffix();
     QString base = QFileInfo(fileName()).completeBaseName();
 
     // Special case for compressed tar archives.
     if (base.right(4).toUpper() == QLatin1String(".TAR")) {
         base.chop(4);
+
+    // Multi-volume 7z's are named name.7z.001.
+    } else if (base.right(3).toUpper() == QLatin1String(".7Z")) {
+        base.chop(3);
+
+    // Multi-volume zip's are named name.zip.001.
+    } else if (base.right(4).toUpper() == QLatin1String(".ZIP")) {
+        base.chop(4);
+
+    // For multivolume rar's we want to remove the ".partNNN" suffix.
+    } else if (suffix.toUpper() == QLatin1String("RAR")) {
+        base.remove(QRegularExpression(QStringLiteral("\\.part[0-9]{1,3}$")));
     }
 
     return base;
@@ -208,9 +222,10 @@ QMimeType Archive::mimeType()
     return m_mimeType;
 }
 
-bool Archive::isReadOnly() const
+bool Archive::isReadOnly()
 {
-    return isValid() ? (m_iface->isReadOnly() || m_isReadOnly) : false;
+    return isValid() ? (m_iface->isReadOnly() || m_isReadOnly ||
+                        (isMultiVolume() && (m_numberOfFiles > 0 || m_numberOfFolders > 0))) : false;
 }
 
 bool Archive::isSingleFolderArchive()
@@ -228,8 +243,12 @@ bool Archive::hasComment() const
     return isValid() ? !comment().isEmpty() : false;
 }
 
-bool Archive::isMultiVolume() const
+bool Archive::isMultiVolume()
 {
+    if (!isValid()) {
+        return false;
+    }
+    listIfNotListed();
     return m_iface->isMultiVolume();
 }
 
@@ -343,6 +362,10 @@ ListJob* Archive::list()
     if (!m_hasBeenListed) {
         connect(job, &ListJob::result, this, &Archive::onListFinished);
     }
+
+    // FIXME: this is only a temporary workaround. See T3300 for a proper fix.
+    m_hasBeenListed = true;
+
     return job;
 }
 
@@ -464,8 +487,6 @@ void Archive::onListFinished(KJob* job)
         // If we already know the password, it means that the archive is header-encrypted.
         m_encryptionType = m_iface->password().isEmpty() ? Encrypted : HeaderEncrypted;
     }
-
-    m_hasBeenListed = true;
 }
 
 void Archive::listIfNotListed()
